@@ -31,4 +31,6 @@ class Transaction(BaseModel):
     shipping_method: Optional[str]
     shipping_upgrade: Optional[str]
     expected_ship_date: Optional[int]
+    buyer_coupon: float
+    shop_coupon: float
     
