@@ -19,8 +19,6 @@ class EtsySession:
                  token_updater: Optional[Callable] = None
                  ):
 
-        
-
         self.CLIENT_KEY = client_key
         self.CLIENT_SECRET = client_secret
         self.__base_endpoint = "https://openapi.etsy.com/v3/application/"
@@ -35,8 +33,9 @@ class EtsySession:
             
             self.__refresh_url = "https://api.etsy.com/v3/public/oauth/token"
             self.__oauth2_session = self.__create_oath2_session()
-            self.__me = Me(**self.request(f"users/me"))
-
+            self.__async_oauth2_session = self.__create_async_oauth2_session()
+            self.__me = None
+            
         else:
             self.__oauth2_session = requests.Session()
 
@@ -51,8 +50,21 @@ class EtsySession:
                                 )
         return session
     
+    def __create_async_oauth2_session(self) -> OAuth2Session:
+        refresh_kwargs = {
+            'client_id': self.CLIENT_KEY,
+            'client_secret': self.CLIENT_SECRET,
+        }
+
+        session = AsyncOAuth2Session(self.CLIENT_KEY, token=self.TOKEN, auto_refresh_kwargs=refresh_kwargs,
+                                auto_refresh_url=self.__refresh_url, token_updater=self.token_updater
+                                )
+        return session
+    
     @property
     def me(self) -> Me:
+        if self.__me is None:
+            self.__me = Me(**self.request(f"users/me"))
         return self.__me
 
     @staticmethod
@@ -88,14 +100,16 @@ class EtsySession:
         return self.create_response(req)
 
     async def async_request(self, endpoint: str, method="GET", headers: Optional[dict] = None, *args, **kwargs) -> dict:
+        
         url = f"{self.__base_endpoint}{endpoint}"
         if headers is None:
             headers = {"x-api-key": self.CLIENT_KEY}
 
-        req = await self.__async_session.get(url=url, headers=headers, *args, **kwargs)
-        json = req.json()
+        async with self.__async_oauth2_session.request(url=url, method=method, headers=headers, *args, **kwargs) as res:
+            
+            json = await res.json()
+            
+            if "error" in json.keys():
+                raise EtsyRequestException(res.status_code, json["error"])
 
-        if "error" in json.keys():
-            raise EtsyRequestException(req.status_code, json["error"])
-
-        return json
+            return json
